@@ -11,6 +11,7 @@ ENABLE_SSH=${ENABLE_SSH:-false}
 SSH_PUBLIC_KEY=${SSH_PUBLIC_KEY:-}
 PYOPTIMIZE_TINYIPA=${PYOPTIMIZE_TINYIPA:-true}
 TINYIPA_REQUIRE_BIOSDEVNAME=${TINYIPA_REQUIRE_BIOSDEVNAME:-false}
+TINYIPA_REQUIRE_IPMITOOL=${TINYIPA_REQUIRE_IPMITOOL:-true}
 
 TC=1001
 STAFF=50
@@ -90,6 +91,9 @@ cp $WORKDIR/build_files/qemu-utils.* $FINALDIR/tmp/builtin/optional
 if $TINYIPA_REQUIRE_BIOSDEVNAME; then
     cp $WORKDIR/build_files/biosdevname.* $FINALDIR/tmp/builtin/optional
 fi
+if $TINYIPA_REQUIRE_IPMITOOL; then
+    cp $WORKDIR/build_files/ipmitool.* $FINALDIR/tmp/builtin/optional
+fi
 
 # Mount /proc for chroot commands
 sudo mount --bind /proc $FINALDIR/proc
@@ -130,15 +134,16 @@ $TC_CHROOT_CMD tce-load -ic /tmp/builtin/optional/qemu-utils.tcz
 if $TINYIPA_REQUIRE_BIOSDEVNAME; then
     $TC_CHROOT_CMD tce-load -ic /tmp/builtin/optional/biosdevname.tcz
 fi
+if $TINYIPA_REQUIRE_IPMITOOL; then
+    $TC_CHROOT_CMD tce-load -ic /tmp/builtin/optional/ipmitool.tcz
+fi
 
 # Ensure tinyipa picks up installed kernel modules
 $CHROOT_CMD depmod -a `$WORKDIR/build_files/fakeuname -r`
 
 # If flag is set install the python now
 if $BUILD_AND_INSTALL_TINYIPA ; then
-    cp -a $BUILDDIR/tmp/upper-constraints.txt $FINALDIR/tmp/upper-constraints.txt
-    $CHROOT_CMD python /tmp/get-pip.py -c /tmp/upper-constraints.txt --no-wheel --no-index --find-links=file:///tmp/wheelhouse ironic_python_agent
-    rm -rf $FINALDIR/tmp/upper-constraints.txt
+    $CHROOT_CMD python /tmp/get-pip.py --no-wheel --no-index --find-links=file:///tmp/wheelhouse --pre ironic_python_agent
     rm -rf $FINALDIR/tmp/wheelhouse
     rm -rf $FINALDIR/tmp/get-pip.py
 fi
